@@ -26,6 +26,49 @@ g_app_info_create_flags_get_type (void)
   return g_define_type_id__volatile;
 }
 
+GType
+g_converter_flags_get_type (void)
+{
+  static volatile gsize g_define_type_id__volatile = 0;
+
+  if (g_once_init_enter (&g_define_type_id__volatile))
+    {
+      static const GFlagsValue values[] = {
+        { G_CONVERTER_NO_FLAGS, "G_CONVERTER_NO_FLAGS", "none" },
+        { G_CONVERTER_INPUT_AT_END, "G_CONVERTER_INPUT_AT_END", "input-at-end" },
+        { G_CONVERTER_FLUSH, "G_CONVERTER_FLUSH", "flush" },
+        { 0, NULL, NULL }
+      };
+      GType g_define_type_id =
+        g_flags_register_static (g_intern_static_string ("GConverterFlags"), values);
+      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
+    }
+
+  return g_define_type_id__volatile;
+}
+
+GType
+g_converter_result_get_type (void)
+{
+  static volatile gsize g_define_type_id__volatile = 0;
+
+  if (g_once_init_enter (&g_define_type_id__volatile))
+    {
+      static const GEnumValue values[] = {
+        { G_CONVERTER_ERROR, "G_CONVERTER_ERROR", "error" },
+        { G_CONVERTER_CONVERTED, "G_CONVERTER_CONVERTED", "converted" },
+        { G_CONVERTER_FINISHED, "G_CONVERTER_FINISHED", "finished" },
+        { G_CONVERTER_FLUSHED, "G_CONVERTER_FLUSHED", "flushed" },
+        { 0, NULL, NULL }
+      };
+      GType g_define_type_id =
+        g_enum_register_static (g_intern_static_string ("GConverterResult"), values);
+      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
+    }
+
+  return g_define_type_id__volatile;
+}
+
 GType
 g_data_stream_byte_order_get_type (void)
 {
@@ -296,6 +339,7 @@ g_file_monitor_flags_get_type (void)
       static const GFlagsValue values[] = {
         { G_FILE_MONITOR_NONE, "G_FILE_MONITOR_NONE", "none" },
         { G_FILE_MONITOR_WATCH_MOUNTS, "G_FILE_MONITOR_WATCH_MOUNTS", "watch-mounts" },
+        { G_FILE_MONITOR_SEND_MOVED, "G_FILE_MONITOR_SEND_MOVED", "send-moved" },
         { 0, NULL, NULL }
       };
       GType g_define_type_id =
@@ -367,6 +411,7 @@ g_file_monitor_event_get_type (void)
         { G_FILE_MONITOR_EVENT_ATTRIBUTE_CHANGED, "G_FILE_MONITOR_EVENT_ATTRIBUTE_CHANGED", "attribute-changed" },
         { G_FILE_MONITOR_EVENT_PRE_UNMOUNT, "G_FILE_MONITOR_EVENT_PRE_UNMOUNT", "pre-unmount" },
         { G_FILE_MONITOR_EVENT_UNMOUNTED, "G_FILE_MONITOR_EVENT_UNMOUNTED", "unmounted" },
+        { G_FILE_MONITOR_EVENT_MOVED, "G_FILE_MONITOR_EVENT_MOVED", "moved" },
         { 0, NULL, NULL }
       };
       GType g_define_type_id =
@@ -419,6 +464,8 @@ g_io_error_enum_get_type (void)
         { G_IO_ERROR_TOO_MANY_OPEN_FILES, "G_IO_ERROR_TOO_MANY_OPEN_FILES", "too-many-open-files" },
         { G_IO_ERROR_NOT_INITIALIZED, "G_IO_ERROR_NOT_INITIALIZED", "not-initialized" },
         { G_IO_ERROR_ADDRESS_IN_USE, "G_IO_ERROR_ADDRESS_IN_USE", "address-in-use" },
+        { G_IO_ERROR_PARTIAL_INPUT, "G_IO_ERROR_PARTIAL_INPUT", "partial-input" },
+        { G_IO_ERROR_INVALID_DATA, "G_IO_ERROR_INVALID_DATA", "invalid-data" },
         { 0, NULL, NULL }
       };
       GType g_define_type_id =
@@ -647,6 +694,27 @@ g_socket_protocol_get_type (void)
   return g_define_type_id__volatile;
 }
 
+GType
+g_zlib_compressor_format_get_type (void)
+{
+  static volatile gsize g_define_type_id__volatile = 0;
+
+  if (g_once_init_enter (&g_define_type_id__volatile))
+    {
+      static const GEnumValue values[] = {
+        { G_ZLIB_COMPRESSOR_FORMAT_ZLIB, "G_ZLIB_COMPRESSOR_FORMAT_ZLIB", "zlib" },
+        { G_ZLIB_COMPRESSOR_FORMAT_GZIP, "G_ZLIB_COMPRESSOR_FORMAT_GZIP", "gzip" },
+        { G_ZLIB_COMPRESSOR_FORMAT_RAW, "G_ZLIB_COMPRESSOR_FORMAT_RAW", "raw" },
+        { 0, NULL, NULL }
+      };
+      GType g_define_type_id =
+        g_enum_register_static (g_intern_static_string ("GZlibCompressorFormat"), values);
+      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
+    }
+
+  return g_define_type_id__volatile;
+}
+
 #define __GIO_ENUM_TYPES_C__
 #include "gioaliasdef.c"
 
